@@ -19,9 +19,15 @@
 */
 //Instructions TODO: RIM, SIM, ~RST
 
-#include "8085-instructions.h"
+#ifdef HAVE_CONFIG_
+#  include <config.h>
+#endif
 
-#define ERR_IV_OP "Invalid Opcode"
+#include "8085-instructions.h"
+//#include <gnome.h> /* for translation macros */ FIXME
+#define _(x) x
+
+#define ERR_IV_OP _("Invalid Opcode")
 
 void _eef_inst_assign_all (void);
 void eef_call_stack_cb (gboolean pushed, gchar x);	/* refer 8085.c */
@@ -857,7 +863,7 @@ static gint
 _eef_inst_func_32 (eef_addr_t opnd_addr)
 {
 	//TODO (page 748)
-	g_warning ("Instruction 'RIM' Not implemented");
+	g_warning (_("Instruction 'RIM' Not implemented"));
 	return 0;
 }
 
@@ -1006,7 +1012,7 @@ static gint
 _eef_inst_func_48 (eef_addr_t opnd_addr)
 {
 	//TODO (page 752)
-	g_warning ("Instruction 'SIM' Not implemented");
+	g_warning (_("Instruction 'SIM' Not implemented"));
 	return 0;
 }
 
