@@ -44,5 +44,5 @@ gint eef_instruction_length (eef_data_t op);
 gboolean
 eef_inst_is_halt_inst (eef_data_t op);
 
-extern G_END_DECLS
+G_END_DECLS
 #endif
